@@ -1,6 +1,7 @@
 // Copyright (C) 1995-1999 David Sugar, Tycho Softworks.
 // Copyright (C) 1999-2005 Open Source Telecom Corp.
-// Copyright (C) 2005-2011 David Sugar, Tycho Softworks.
+// Copyright (C) 2005-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU ccAudio2.
 //
@@ -31,7 +32,7 @@
 #include <ucommon/ucommon.h>
 #endif
 
-NAMESPACE_UCOMMON
+namespace ucommon {
 
 #define AUDIO_SIGNED_LINEAR_RAW 1
 #define AUDIO_LINEAR_CONVERSION 1
@@ -716,7 +717,7 @@ public:
      * @return sample rate in samples per second.
      */
     inline Rate getRate(void) const
-        {return rate;};
+        {return rate;}
 
     /**
      * Get the frame size for the number of audio samples generated.
@@ -724,7 +725,7 @@ public:
      * @return number of samples processed in frame.
      */
     inline size_t getSamples(void) const
-        {return samples;};
+        {return samples;}
 
     /**
      * Test if the tone generator is currently set to silence.
@@ -838,7 +839,7 @@ public:
      * @return audio encoding of this object.
      */
     inline Encoding getEncoding(void) const
-        {return info.encoding;};
+        {return info.encoding;}
 
     /**
      * Generic sample rate.
@@ -846,7 +847,7 @@ public:
      * @return audio sample rate of this object.
      */
     inline unsigned getSampleRate(void) const
-        {return info.rate;};
+        {return info.rate;}
 
     /**
      * Abstract interface to put raw data.
@@ -874,7 +875,7 @@ public:
      * @param data to get.
      */
     inline ssize_t getPacket(Encoded data)
-        {return getBuffer(data, 0);};
+        {return getBuffer(data, 0);}
 
     /**
      * Get raw data and assure is in native machine endian.
@@ -1008,7 +1009,7 @@ protected:
      * @return next file to open or NULL when done.
      */
     virtual char *getContinuation(void)
-        {return NULL;};
+        {return NULL;}
 
     /**
      * Return a human-readable error message given a numeric error
@@ -1029,7 +1030,7 @@ protected:
      * @return number of bytes in file header.
      */
     inline unsigned long getHeader(void) const
-        {return header;};
+        {return header;}
 
     /**
      * Convert binary 2 byte data stored in the order specified
@@ -1095,7 +1096,7 @@ public:
      * Construct an audio file without attaching to the filesystem.
      */
     inline AudioFile()
-        {initialize();};
+        {initialize();}
 
     virtual ~AudioFile();
 
@@ -1137,7 +1138,7 @@ public:
      * @return max frame size in bytes.
      */
     inline size_t getSize(void)
-        {return maxFramesize(info);};
+        {return maxFramesize(info);}
 
     /**
      * Close an object associated with an open file.  This
@@ -1332,7 +1333,7 @@ public:
      * @return audio encoding format.
      */
     inline Encoding getEncoding(void) const
-        {return info.encoding;};
+        {return info.encoding;}
 
     /**
      * Return base file format of containing audio file.
@@ -1340,7 +1341,7 @@ public:
      * @return audio file container format.
      */
     inline Format getFormat(void) const
-        {return info.format;};
+        {return info.format;}
 
     /**
      * Get audio encoding sample rate, in samples per second, for
@@ -1349,7 +1350,7 @@ public:
      * @return sample rate.
      */
     inline unsigned getSampleRate(void) const
-        {return info.rate;};
+        {return info.rate;}
 
     /**
      * Get annotation extracted from header of containing file.
@@ -1357,7 +1358,7 @@ public:
      * @return annotation text if any, else NULL.
      */
     inline char *getAnnotation(void) const
-        {return info.annotation;};
+        {return info.annotation;}
 
     /**
      * Get last error code.
@@ -1365,13 +1366,13 @@ public:
      * @return alst error code.
      */
     inline Error getError(void) const
-        {return error;};
+        {return error;}
 
     inline operator bool() const
-        {return is_open();};
+        {return is_open();}
 
     inline bool operator!(void) const
-        {return (bool)!is_open();};
+        {return (bool)!is_open();}
 
     /**
      * Return if the current content is signed or unsigned samples.
@@ -1601,7 +1602,7 @@ public:
      * @return codec used.
      */
     inline AudioCodec *getCodec(void)
-        {return codec;};
+        {return codec;}
 };
 
 /**
@@ -1633,7 +1634,7 @@ protected:
      * @param format name from spd.
      */
     virtual AudioCodec *getByFormat(const char *format)
-        {return this;};
+        {return this;}
 
     /**
      * get a codec by audio source info descriptor.
@@ -1642,7 +1643,7 @@ protected:
      * @param info audio source descriptor.
      */
     virtual AudioCodec *getByInfo(Info &info)
-        {return this;};
+        {return this;}
 
 public:
     /**
@@ -1654,12 +1655,12 @@ public:
     AudioCodec(const char *name, Encoding encoding);
 
     inline const char *getName(void) const
-        {return name;};
+        {return name;}
 
     inline const char *getDescription(void) const
-        {return info.annotation;};
+        {return info.annotation;}
 
-    virtual ~AudioCodec() {};
+    virtual ~AudioCodec() {}
 
     /**
      * End use of a requested codec.  If constructed then will be
@@ -1793,7 +1794,7 @@ public:
      * @return info.
      */
     inline Info getInfo(void) const
-        {return info;};
+        {return info;}
 };
 
 class __EXPORT AudioDevice : public AudioBase
@@ -1802,7 +1803,7 @@ protected:
     bool enabled;
 
 public:
-    virtual ~AudioDevice() {};
+    virtual ~AudioDevice() {}
 
     /**
      * Copy linear samples to an audio device through its virtual.
@@ -1850,7 +1851,7 @@ public:
      * @param info source description for device settings.
      */
     virtual bool setEncoded(Info &info)
-        {return false;};
+        {return false;}
 
     /**
      * Set properties for audio device.
@@ -1869,7 +1870,7 @@ public:
      * can handle it.
      */
     virtual void sync(void)
-        {return;};
+        {return;}
 
     /**
      * Flush any pending buffered samples in audio device.
@@ -1904,7 +1905,7 @@ public:
      * @return audio device descriptor.
      */
     inline const Info *getInfo(void) const
-        {return &info;};
+        {return &info;}
 
     /**
      * Whether device is currently enabled.  If invalid audio
@@ -1915,7 +1916,7 @@ public:
      * @see #setAudio #setInfo
      */
     inline bool is_enabled(void) const
-        {return enabled;};
+        {return enabled;}
 };
 
 /**
@@ -2112,7 +2113,7 @@ private:
     tone_detection_descriptor_t fax_detect_2nd;
 };
 
-END_NAMESPACE
+} // namespace ucommon
 
 #endif
 
