@@ -1,5 +1,6 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU ccAudio2.
 //
@@ -17,7 +18,7 @@
 // along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <ucommon/ucommon.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 #ifdef  HAVE_ENDIAN_H
 #include <endian.h>
 #endif
@@ -37,7 +38,7 @@
 #define __BYTE_ORDER    __LITTLE_ENDIAN
 #endif
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 #ifdef  _PACKED
 #pragma pack(1)
@@ -1037,7 +1038,7 @@ void AudioFile::open(const char *name, Mode m, timeout_t framing)
     goto done;
 
 mp3:
-    framing = 0;
+    //framing = 0;
     afSeek(header);
 
     info.order = __BIG_ENDIAN;
@@ -1370,8 +1371,6 @@ rescan:
     }
     if (iolimit && ((curpos + bytes) > iolimit))
         bytes = iolimit - curpos;
-    if (bytes < 0)
-        bytes = 0;
 
     getInfo(&prior);
 
@@ -1543,8 +1542,6 @@ Audio::Error AudioFile::skip(long samples)
 {
     unsigned long orig = getPosition();
     unsigned long pos = orig + samples;
-    if(pos < 0)
-        pos = 0;
 
     setPosition(pos);
     if(orig < getPosition())
@@ -1606,5 +1603,4 @@ void AudioFile::getPosition(char *timestamp, size_t size)
     toTimestamp(pos * info.framing, timestamp, size);
 }
 
-
-
+} // namespace ucommon
