@@ -1,5 +1,6 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU ccAudio2.
 //
@@ -37,9 +38,9 @@
 #define __BYTE_ORDER    __LITTLE_ENDIAN
 #endif
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
-class AudioRegistry
+class __LOCAL AudioRegistry
 {
 public:
     AudioRegistry();
@@ -429,6 +430,9 @@ Audio::Level Audio::impulse(Encoding encoding, void *buffer, unsigned samples)
     if(!samples)
         samples = getCount(encoding);
 
+    if(!samples)
+        return 0;
+
     switch(encoding) {
     case cdaStereo:
     case pcm16Stereo:
@@ -480,6 +484,9 @@ Audio::Level Audio::impulse(Info &info, void *buffer, unsigned samples)
     if(!samples)
         samples = getCount(info.encoding);
 
+    if(!samples)
+        return 0;
+
     switch(info.encoding) {
     case cdaStereo:
     case pcm16Stereo:
@@ -1214,3 +1221,4 @@ AudioDevice *Audio::getDevice(unsigned index, DeviceMode mode)
 
 #endif
 
+} // namespace ucommon
