@@ -1,4 +1,6 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -36,7 +38,7 @@
 //
 
 #include <ucommon/ucommon.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 
 extern int _osx_ccaudio_dummy;
 int _osx_ccaudio_dummy = 0;
@@ -100,7 +102,7 @@ static bool scanDevices(unsigned index)
     return true;
 }
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 bool Audio::is_available(unsigned index)
 {
@@ -115,5 +117,7 @@ AudioDevice *Audio::getDevice(unsigned index, DeviceMode mode)
     return NULL;
 }
 
+} // namespace ucommon
+
 
 #endif
