@@ -1,5 +1,6 @@
 // Copyright (C) 2000-2005 Open Source Telecom Corporation.
-// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU ccAudio2.
 //
@@ -17,11 +18,11 @@
 // along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <ucommon/ucommon.h>
-#include <config.h>
+#include <ccaudio2-config.h>
 #include <ucommon/export.h>
 #include <ccaudio2.h>
 
-using namespace UCOMMON_NAMESPACE;
+namespace ucommon {
 
 AudioResample::AudioResample(Rate div, Rate mul)
 {
@@ -108,3 +109,5 @@ size_t AudioResample::process(Linear from, Linear dest, size_t count)
     }
     return saved;
 }
+
+} // namespace ucommon
